class InventoryHelper:

    lines = []

    def add_group(self, group_name: str, content: []):
        self.lines.append(f'[{group_name}]')

        [self.lines.append(i) for i in content]

    def generate_inventory_file(self, output_file: str):
        inventory_file = open(output_file, "w")
        [inventory_file.write(f'{i}\n') for i in self.lines]
        inventory_file.close()



from ansible import context
from ansible.cli import CLI
from ansible.module_utils.common.collections import ImmutableDict
from ansible.executor.playbook_executor import PlaybookExecutor
from ansible.parsing.dataloader import DataLoader
from ansible.inventory.manager import InventoryManager
from ansible.vars.manager import VariableManager


class AnsibleHelper:

    connection_type: str = "ssh"
    become_method: str = "sudo"
    become_user: str = "root"

    def run_playbook(self, inventory_file: str, playbook_file: str, remote_user: str):

        loader = DataLoader()

        context.CLIARGS = ImmutableDict(tags={}, listtags=False, listtasks=False,
                                        listhosts=False, syntax=False,
                                        connection=self.connection_type, module_path=None,
                                        forks=100, remote_user=remote_user, private_key_file=None,
                                        ssh_common_args=None, ssh_extra_args=None,
                                        sftp_extra_args=None, scp_extra_args=None, become=True,
                                        become_method=self.become_method,
                                        become_user=self.become_user, verbosity=True,
                                        check=False, start_at_task=None)

        inventory = InventoryManager(loader=loader, sources=(inventory_file,))

        variable_manager = VariableManager(loader=loader, inventory=inventory,
                                           version_info=CLI.version_info(gitinfo=False))

        playbook_executor = PlaybookExecutor(playbooks=[playbook_file], inventory=inventory,
                                             variable_manager=variable_manager, loader=loader,
                                             passwords={})

        playbook_executor.run()



from shutil import which
import os
from urllib import request
import click
from common.InventoryHelper import InventoryHelper


class Utils:

    @staticmethod
    def create_working_path(target: str) -> str:
        target_folder_name = target
        iterate = 0
        if os.path.isdir(target_folder_name):
            target_folder_name = f'{target_folder_name}_{iterate}'

            while os.path.isdir(target_folder_name):
                target_folder_name = f'{target}_{iterate}'
                iterate += 1
        os.mkdir(target_folder_name)
        return target_folder_name

    @staticmethod
    def get_playbook_from_git(url: str, output_file: str) -> str:
        base_yaml: request = request.urlopen(url)

        if base_yaml.getcode() != 200:
            click.echo(f'Request failed. Check your internet connection and repeat [{url}]')
            exit(1)

        playbook_file = open(output_file, "w")
        playbook_file.write(base_yaml.read().decode("utf-8"))
        playbook_file.close()

        return output_file

    @staticmethod
    def create_ini_file(user_ssh: str, database_host: str, root_database_password: str, output_file: str):
        inventory = InventoryHelper()

        if user_ssh and user_ssh != "":
            pb_vars = [
                'ansible_connection=ssh',
                f'ansible_ssh_user={user_ssh}',
                f'mysql_password={root_database_password}'
            ]
        else:
            pb_vars = [
                f'mysql_password={root_database_password}'
            ]
        inventory.add_group("all:vars", pb_vars)

        inventory.add_group("database", [
            f'{database_host}'
        ])

        inventory.generate_inventory_file(output_file)



from setuptools import setup, find_packages
import os
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='tools-automator',
    long_description=long_description,
    long_description_content_type="text/markdown",
    version=os.environ['RELEASE_VERSION'],
    py_modules=['main'],
    install_requires=[
        'Click',
        'pexpect',
        'ansible'
    ],
    entry_points={
        'console_scripts': [
            'create_mysql = mysql:create_mysql',
        ],
    },
    author="João André Simões",
    author_email="jarpsimoes@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7"
    ],
    packages=find_packages(exclude="tests"),
    include_package_data=True
)
